@@ -909,7 +909,7 @@ quit:
 	free(valid_str);
 	free(refresh_str);
 	free(last_update_str);
-	return 0;
+	return retval;
 }
 #endif
 
@@ -1634,7 +1634,6 @@ void db_free_notifs() {
 static int daemon_listen(thread_t *t, const char *name, char *port, int *conn_out) {
 	struct	addrinfo *ai;
 	struct	addrinfo hints;
-	char	pretty_addr[256];
 	int	conn;
 	int 	gaie;
 	const int	zero = 0;
@@ -1648,10 +1647,8 @@ static int daemon_listen(thread_t *t, const char *name, char *port, int *conn_ou
 	gaie = getaddrinfo (name, port, &hints, &ai);
 	if (gaie != 0 || ai == NULL) {
 		hints.ai_family = 0;
-		gaie = getaddrinfo (NULL, port, &hints, &ai);
+		gaie = getaddrinfo (name, port, &hints, &ai);
 	}
-
-	gaie = getaddrinfo (name, port, &hints, &ai);
 	if (gaie != 0) {
 		lprintf(t, ERR, "getaddrinfo: %s", gai_strerror (gaie));
 		return 1;
